transaction_hashes_for_any_block

Function transaction_hashes_for_any_block 

pub fn transaction_hashes_for_any_block<'a>(
    chains: impl Iterator<Item = &'a Arc<Chain>>,
    db: &ZebraDb,
    hash_or_height: HashOrHeight,
) -> Option<(Arc<[Hash]>, bool)>
Returns the transaction::Hashes for the block with hash_or_height, if it exists in any chain in chains or finalized db. The first chain in chains must be the best chain.

The returned hashes are in block order.

Returns None if the block is not found.